use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
irc
Caleb
Cushing
xenoterracide
Marcel
Gruenauer
hanekomu
Karen
Etheridge
ether
Randy
Stauner
rwstauner
Graham
Knop
haarg
David
Golden
dagolden
Harley
Pig
harleypig
Alexandr
Ciornii
alexchorny
Breno
de
Oliveira
garu
lib
Dist
Zilla
Plugin
PodSpellingTests
Test
PodSpelling
